@@ -1,6 +1,9 @@
 from .osu.osu_parser import OsuFile
 from .osr.osr_parser import ReplayFile
-from .osr.constants import Key, KeyMania, KeyTaiko, OsuReplayFrame, TaikoReplayFrame, ManiaReplayFrame, CatchReplayFrame
+from .osr.constants import OsuReplayFrame
+from .osr.constants import TaikoReplayFrame
+from .osr.constants import ManiaReplayFrame
+from .osr.constants import CatchReplayFrame
 from .osu.objects import Circle
 from .osu.objects import Spinner
 from .osu.objects import Slider
